package sun.java2d.opengl;

import sun.java2d.SurfaceData;
import java.awt.GraphicsEnvironment;
import java.awt.Rectangle;
import java.awt.Image;
import sun.awt.SunToolkit;
import java.awt.Component;
import java.awt.GraphicsConfiguration;
import java.awt.image.ColorModel;
import sun.awt.windows.WComponentPeer;

public abstract class WGLSurfaceData extends OGLSurfaceData
{
    protected WComponentPeer peer;
    private WGLGraphicsConfig graphicsConfig;
    
    private native void initOps(OGLGraphicsConfig p0, long p1, WComponentPeer p2, long p3);
    
    protected WGLSurfaceData(WComponentPeer peer, WGLGraphicsConfig graphicsConfig, ColorModel colorModel, int n) {
        super(graphicsConfig, colorModel, n);
        this.peer = peer;
        this.initOps(this.graphicsConfig = graphicsConfig, graphicsConfig.getNativeConfigInfo(), peer, (peer != null) ? peer.getHWnd() : 0L);
    }
    
    @Override
    public GraphicsConfiguration getDeviceConfiguration() {
        return this.graphicsConfig;
    }
    
    public static WGLSurfaceData.WGLWindowSurfaceData createData(WComponentPeer wComponentPeer) {
        if (!wComponentPeer.isAccelCapable() || !SunToolkit.isContainingTopLevelOpaque((Component)wComponentPeer.getTarget())) {
            return null;
        }
        return new WGLSurfaceData.WGLWindowSurfaceData(wComponentPeer, getGC(wComponentPeer));
    }
    
    public static WGLSurfaceData.WGLOffScreenSurfaceData createData(WComponentPeer wComponentPeer, Image image, int n) {
        if (!wComponentPeer.isAccelCapable() || !SunToolkit.isContainingTopLevelOpaque((Component)wComponentPeer.getTarget())) {
            return null;
        }
        WGLGraphicsConfig gc = getGC(wComponentPeer);
        Rectangle bounds = wComponentPeer.getBounds();
        if (n == 4) {
            return new WGLSurfaceData.WGLOffScreenSurfaceData(wComponentPeer, gc, bounds.width, bounds.height, image, wComponentPeer.getColorModel(), n);
        }
        return new WGLSurfaceData.WGLVSyncOffScreenSurfaceData(wComponentPeer, gc, bounds.width, bounds.height, image, wComponentPeer.getColorModel(), n);
    }
    
    public static WGLSurfaceData.WGLOffScreenSurfaceData createData(WGLGraphicsConfig wglGraphicsConfig, int n, int n2, ColorModel colorModel, Image image, int n3) {
        return new WGLSurfaceData.WGLOffScreenSurfaceData(null, wglGraphicsConfig, n, n2, image, colorModel, n3);
    }
    
    public static WGLGraphicsConfig getGC(WComponentPeer wComponentPeer) {
        if (wComponentPeer != null) {
            return (WGLGraphicsConfig)wComponentPeer.getGraphicsConfiguration();
        }
        return (WGLGraphicsConfig)GraphicsEnvironment.getLocalGraphicsEnvironment().getDefaultScreenDevice().getDefaultConfiguration();
    }
    
    public static native boolean updateWindowAccelImpl(long p0, WComponentPeer p1, int p2, int p3);
    
    public static class WGLWindowSurfaceData extends WGLSurfaceData
    {
        public WGLWindowSurfaceData(WComponentPeer wComponentPeer, WGLGraphicsConfig wglGraphicsConfig) {
            super(wComponentPeer, wglGraphicsConfig, wComponentPeer.getColorModel(), 1);
        }
        
        @Override
        public SurfaceData getReplacement() {
            return this.peer.getSurfaceData();
        }
        
        @Override
        public Rectangle getBounds() {
            Rectangle bounds;
            Rectangle rectangle = bounds = this.peer.getBounds();
            int n = 0;
            rectangle.y = n;
            bounds.x = n;
            return rectangle;
        }
        
        @Override
        public Object getDestination() {
            return this.peer.getTarget();
        }
    }
    
    public static class WGLVSyncOffScreenSurfaceData extends WGLSurfaceData.WGLOffScreenSurfaceData
    {
        private WGLSurfaceData.WGLOffScreenSurfaceData flipSurface;
        
        public WGLVSyncOffScreenSurfaceData(WComponentPeer wComponentPeer, WGLGraphicsConfig wglGraphicsConfig, int n, int n2, Image image, ColorModel colorModel, int n3) {
            super(wComponentPeer, wglGraphicsConfig, n, n2, image, colorModel, n3);
            this.flipSurface = WGLSurfaceData.createData(wComponentPeer, image, 4);
        }
        
        public SurfaceData getFlipSurface() {
            return this.flipSurface;
        }
        
        @Override
        public void flush() {
            this.flipSurface.flush();
            super.flush();
        }
    }
    
    public static class WGLOffScreenSurfaceData extends WGLSurfaceData
    {
        private Image offscreenImage;
        private int width;
        private int height;
        
        public WGLOffScreenSurfaceData(WComponentPeer wComponentPeer, WGLGraphicsConfig wglGraphicsConfig, int width, int height, Image offscreenImage, ColorModel colorModel, int n) {
            super(wComponentPeer, wglGraphicsConfig, colorModel, n);
            this.width = width;
            this.height = height;
            this.offscreenImage = offscreenImage;
            this.initSurface(width, height);
        }
        
        @Override
        public SurfaceData getReplacement() {
            return SurfaceData.restoreContents(this.offscreenImage);
        }
        
        @Override
        public Rectangle getBounds() {
            if (this.type == 4) {
                Rectangle bounds;
                Rectangle rectangle = bounds = this.peer.getBounds();
                int n = 0;
                rectangle.y = n;
                bounds.x = n;
                return rectangle;
            }
            return new Rectangle(this.width, this.height);
        }
        
        @Override
        public Object getDestination() {
            return this.offscreenImage;
        }
    }
}
